@@ -30,7 +30,7 @@ class NumberFormat(UnicodeMixin, ImmutableMixin):
                  format=None,
                  leading_digits_pattern=None,
                  national_prefix_formatting_rule=None,
-                 national_prefix_optional_when_formatting=False,
+                 national_prefix_optional_when_formatting=None,
                  domestic_carrier_code_formatting_rule=None):
         # pattern is a regex that is used to match the national (significant)
         # number. For example, the pattern "(20)(\d{4})(\d{4})" will match
@@ -93,7 +93,10 @@ class NumberFormat(UnicodeMixin, ImmutableMixin):
         # set to true. This will be inherited from the value set for the
         # territory in the XML file, unless a national_prefix_formatting_rule
         # is defined specifically for this NumberFormat.
-        self.national_prefix_optional_when_formatting = bool(national_prefix_optional_when_formatting)
+        if national_prefix_optional_when_formatting is not None:
+            self.national_prefix_optional_when_formatting = bool(national_prefix_optional_when_formatting)
+        else:
+            self.national_prefix_optional_when_formatting = None
 
         # This field specifies how any carrier code ($CC) together with the
         # first group ($FG) in the national significant number should be
@@ -110,7 +113,8 @@ class NumberFormat(UnicodeMixin, ImmutableMixin):
         self.leading_digits_pattern.extend(other.leading_digits_pattern)
         if other.national_prefix_formatting_rule is not None:
             self.national_prefix_formatting_rule = other.national_prefix_formatting_rule
-        self.national_prefix_optional_when_formatting = other.national_prefix_optional_when_formatting
+        if other.national_prefix_optional_when_formatting is not None:
+            self.national_prefix_optional_when_formatting = other.national_prefix_optional_when_formatting
         if other.domestic_carrier_code_formatting_rule is not None:
             self.domestic_carrier_code_formatting_rule = other.domestic_carrier_code_formatting_rule
 
@@ -134,7 +138,7 @@ class NumberFormat(UnicodeMixin, ImmutableMixin):
                        unicod(", ").join([rpr(ld) for ld in self.leading_digits_pattern]))
         if self.national_prefix_formatting_rule is not None:
             result += unicod(", national_prefix_formatting_rule=%s") % rpr(self.national_prefix_formatting_rule)
-        if self.national_prefix_optional_when_formatting:
+        if self.national_prefix_optional_when_formatting is not None:
             result += unicod(", national_prefix_optional_when_formatting=%s") % str(self.national_prefix_optional_when_formatting)
         if self.domestic_carrier_code_formatting_rule is not None:
             result += unicod(", domestic_carrier_code_formatting_rule=%s") % rpr(self.domestic_carrier_code_formatting_rule)
@@ -147,7 +151,6 @@ class PhoneNumberDesc(UnicodeMixin, ImmutableMixin):
     @mutating_method
     def __init__(self,
                  national_number_pattern=None,
-                 possible_number_pattern=None,
                  example_number=None,
                  possible_length=None,
                  possible_length_local_only=None):
@@ -156,14 +159,8 @@ class PhoneNumberDesc(UnicodeMixin, ImmutableMixin):
         # its total length and leading digits.
         self.national_number_pattern = force_unicode(national_number_pattern)  # None or Unicode string holding regexp
 
-        # The possible_number_pattern represents what a potentially valid
-        # phone number for this region may be written as. This is a superset
-        # of the national_number_pattern above and includes numbers that have
-        # the area code omitted. Typically the only restrictions here are in
-        # the number of digits.  This could be used to highlight tokens in a
-        # text that may be a phone number, or to quickly prune numbers that
-        # could not possibly be a phone number for this locale.
-        self.possible_number_pattern = force_unicode(possible_number_pattern)  # None or Unicode string holding regexp
+        # The possible_number_pattern is now retired.
+        self.possible_number_pattern = None
 
         # An example national significant number for the specific type. It
         # should not contain any formatting information.
@@ -200,8 +197,6 @@ class PhoneNumberDesc(UnicodeMixin, ImmutableMixin):
         """Merge information from another PhoneNumberDesc object into this one."""
         if other.national_number_pattern is not None:
             self.national_number_pattern = other.national_number_pattern
-        if other.possible_number_pattern is not None:
-            self.possible_number_pattern = other.possible_number_pattern
         if other.example_number is not None:
             self.example_number = other.example_number
 
@@ -223,9 +218,6 @@ class PhoneNumberDesc(UnicodeMixin, ImmutableMixin):
         if self.national_number_pattern is not None:
             result += unicod("%snational_number_pattern=%s") % (sep, rpr(self.national_number_pattern))
             sep = unicod(", ")
-        if self.possible_number_pattern is not None:
-            result += unicod("%spossible_number_pattern=%s") % (sep, rpr(self.possible_number_pattern))
-            sep = unicod(", ")
         if self.example_number is not None:
             result += unicod("%sexample_number=%s") % (sep, rpr(self.example_number))
             sep = unicod(", ")
@@ -371,8 +363,7 @@ class PhoneMetadata(UnicodeMixin, ImmutableMixin):
         # are missing altogether, they will inherit all fields from the
         # general_desc. For all other types, if the whole type is missing and
         # it is relevant for the metadata, it will be given a
-        # national_number_pattern of "NA" and a possible_number_pattern of
-        # "NA".
+        # national_number_pattern of "NA".
         self.general_desc = general_desc  # None or PhoneNumberDesc
         self.fixed_line = fixed_line  # None or PhoneNumberDesc
         self.mobile = mobile  # None or PhoneNumberDesc
